@@ -1,8 +1,6 @@
-#!/usr/local/bin/perl -w
-
 # Infoseek.pm
 # Copyright (C) 1998 by Martin Thurn
-# $Id: Infoseek.pm,v 1.11 1998/10/06 00:53:12 johnh Exp $
+# $Id: Infoseek.pm,v 1.13 1999/05/27 23:15:53 johnh Exp $
 
 =head1 NAME
 
@@ -34,21 +32,6 @@ be done through L<WWW::Search> objects.
 
 To make new back-ends, see L<WWW::Search>.
 
-=head1 HOW DOES IT WORK?
-
-C<native_setup_search> is called (from C<WWW::Search::setup_search>)
-before we do anything.  It initializes our private variables (which
-all begin with underscore) and sets up a URL to the first results
-page in C<{_next_url}>.
-
-C<native_retrieve_some> is called (from C<WWW::Search::retrieve_some>)
-whenever more hits are needed.  It calls C<WWW::Search::http_request>
-to fetch the page specified by C<{_next_url}>.
-It then parses this page, appending any search hits it finds to 
-C<{cache}>.  If it finds a ``next'' button in the text,
-it sets C<{_next_url}> to point to the page for the next
-set of results, otherwise it sets it to undef to indicate we''re done.
-
 =head1 BUGS
 
 Please tell the author if you find any!
@@ -72,11 +55,26 @@ MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 =head1 VERSION HISTORY
 
-If it''s not listed here, then it wasn''t a meaningful nor released revision.
+If it is not listed here, then it was not a meaningful nor released revision.
+
+=head2 1.12, 1999-05-21
+
+www.infoseek.com changed their output format.
+Unfortunately, Companies and News search don't work.
+
+=head2 1.11, 1999-04-27
+
+Fixed BUG in parsing of News search results.
+Added version method.
+
+=head2 1.08, 1999-02-09
+
+Fixed BUG in parsing of Companies search results.
+Thanks to Jim Smyser (jsmyser@bigfoot.com) for pointing it out.
 
 =head2 1.7, 1998-10-05
 
-www.Infoseek.com changed their output format.
+www.infoseek.com changed their output format.
 Thanks to Andreas Borchert (borchert@mathematik.uni-ulm.de) for patches.
 
 =head2 1.6, 1998-09-18
@@ -85,7 +83,7 @@ Fixed BUG where (apparently) no titles were retrieved.
 
 =head2 1.5
 
-www.Infoseek.com changed their output format ever-so-slightly.
+www.infoseek.com changed their output format ever-so-slightly.
 
 =head2 1.3
 
@@ -101,12 +99,14 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$VERSION = '1.12';
 
 use Carp ();
 use WWW::Search(generic_option);
 require WWW::SearchResult;
 
+# public
+sub version { $VERSION }
 
 # private
 sub native_setup_search
@@ -196,6 +196,9 @@ sub native_retrieve_some
   # Fast exit if already done:
   return undef unless defined($self->{_next_url});
   
+  # A macro for HTML whitespace:
+  my $SPACE = '(&nbsp;|\s)+';
+
   # If this is not the first page of results, sleep so as to not overload the server:
   $self->user_agent_delay if 1 < $self->{'_next_to_retrieve'};
   
@@ -211,26 +214,30 @@ sub native_retrieve_some
   print STDERR " *   got response\n" if $self->{'_debug'};
   $self->{'_next_url'} = undef;
   # Parse the output
-  my ($START, $HEADER, $HITS, $DESC,$PERCENT,$SIZE,$DATE, $NEXT,$COMP_NEXT, $TRAILER) = qw( ST HE HI DE PE SI DA NE CN TR );
+  my ($START, $HEADER, $HITS, $DESC,$PERCENT,$SIZE,$DATE, $NEXT,$COMP_NEXT, $TRAILER,
+     $WEB_HITS, $WEB_NEXT) = qw( ST HE HI DE PE SI DA NE CN TR WH WN );
   my $hits_found = 0;
   my $state = $START;
   my $hit;
-  foreach (split(/\n/, $response->content())) 
+  foreach ($self->split_lines($response->content())) 
     {
     next if m/^$/; # short circuit for blank lines
     print STDERR " *   $state ===$_===" if 2 <= $self->{'_debug'};
     if ($state eq $START && 
-	m=RESULT.*?\s+of\s+([\d,]+)\s+total results=i) # afb 10/98
+	m=web\ssearch\sresults=i &&
+	m=of\s+<b>([\d,]+)</b>\s+results=i)
       {
       # Actual line of input is:
-      # <b>RESULTS 1 - 25</b>  of 192 total results
-      print STDERR "header line\n" if 2 <= $self->{'_debug'};
+      # <tr><td valign="middle" align="left" nowrap colspan="3"><font face="Helvetica,Arial" size="3" color="#FFFFFF"><a name="search">&nbsp;<b>Web search results</b>&nbsp;&nbsp;&nbsp;&nbsp;<font face="Helvetica,Arial" size="2">1 - 10 of <b>99</b> results most relevant to <b>martin thurn</b> </font>&nbsp;</a></font></td>
+      print STDERR "web header line\n" if 2 <= $self->{'_debug'};
       my $iCount = $1;
       $iCount =~ s/,//g;
       $self->approximate_result_count($iCount);
-      $state = $HEADER;
-      } # we're in START mode, and line has number of results
-    elsif ($state eq $START && 
+      $state = $NEXT;
+      next;
+      } # we're in START mode, and line has number of WEB results
+
+    if ($state eq $START && 
            m=<b>ARTICLES\s+\d+\s+-\s+\d+</b>\s+of\s+([0-9,]+)=)
       {
       # Actual line of input is:
@@ -240,47 +247,96 @@ sub native_retrieve_some
       $iCount =~ tr/[^0-9]//;
       $self->approximate_result_count($1);
       $state = $HEADER;
+      next;
       } # we're in START mode, and line has number of results
 
-    elsif ($state eq $HEADER && 
-           m@roup\sthese\sresults@)
-      {
-      # Actual line of input is:
-      # <a href="/Titles?qt=star+wars+collector&col=WW&nh=25&rf=0">Ungroup these results</a>
-      print STDERR "group/ungroup line\n" if 2 <= $self->{'_debug'};
-      $state = $NEXT;
-      } # we're in HEADER mode, and line talks about (un)grouping results
-    elsif ($state eq $HEADER && 
-           m@>Hide\ssummaries<@i)
-      {
-      # Actual line of input is:
-      # <a href="/Titles?qt=star+wars+collector&col=WW&nh=25&rf=0">Ungroup these results</a>
-      print STDERR "show/hide summaries line\n" if 2 <= $self->{'_debug'};
-      $state = $COMP_NEXT;
-      } # we're in HEADER mode, and line talks about (un)grouping results
+#      if ($state eq $HEADER && 
+#             m@roup\sthese\sresults@)
+#        {
+#        # Actual line of input is:
+#        # <a href="/Titles?qt=star+wars+collector&col=WW&nh=25&rf=0">Ungroup these results</a>
+#        print STDERR "group/ungroup line\n" if 2 <= $self->{'_debug'};
+#        $state = $NEXT;
+#        next;
+#        } # we're in HEADER mode, and line talks about (un)grouping results
+#      if ($state eq $HEADER && 
+#             m@>Hide\ssummaries<@i)
+#        {
+#        # Actual line of input is:
+#        # <b><a href="http://infoseek.go.com/Titles?rf=0&qt=Lycos&col=HV&nh=20&st=0&&sf=1&ud4=1"><font size="-1">Hide summaries</font></a></b>
+#        print STDERR "show/hide summaries line\n" if 2 <= $self->{'_debug'};
+#        $state = $COMP_NEXT;
+#        next;
+#        } # we're in HEADER mode, and line talks about hide summaries
 
-    elsif (($state eq $NEXT || $state eq $COMP_NEXT) &&
-           m@>Next(&nbsp;|\s+)\d+@i)
+    if ((($state eq $NEXT) || 
+         ($state eq $WEB_NEXT)) &&
+        s@<a href=\"(.*?)\">Next$SPACE\d+@WWWSEARCHDELETED@i)
       {
       # Actual line of input is:
-      #    &nbsp;&nbsp;|&nbsp;&nbsp;<a href="/Titles?qt=star+wars+collector&rf=11&st=50&nh=25&rf=11">Next&nbsp;25</a>
-      print STDERR " found next button\n" if 2 <= $self->{'_debug'};
-      # There is a "next" button on this page, therefore there are
+      # <font face="Helvetica,Arial" size="2"><b><a href="http://infoseek.go.com/Titles?qt=martin+thurn&col=WW&sv=IS&lk=noframes&svx=home_searchbox&st=10">Next 10 ></a></b> &nbsp;|&nbsp; ...
+      print STDERR " found 'next' link\n" if 2 <= $self->{'_debug'};
+      # There is a "next" link on this page, therefore there are
       # indeed more results for us to go after next time.
-      # Process the options.
-      $self->{'_next_to_retrieve'} += $self->{'_hits_per_page'};
-      $self->{'_options'}{'st'} = $self->{'_next_to_retrieve'};
-      my($options) = '';
-      foreach (keys %{$self->{_options}}) 
-        {
-        next if (generic_option($_));
-        $options .= $_ . '=' . $self->{_options}{$_} . '&';
-        }
-      # Finally, figure out the url.
-      $self->{_next_url} = $self->{_options}{'search_url'} .'?'. $options;
-      $state = $HITS;
+      # # Process the options.
+      # $self->{'_next_to_retrieve'} += $self->{'_hits_per_page'};
+      # $self->{'_options'}{'st'} = $self->{'_next_to_retrieve'};
+      # my($options) = '';
+      # foreach (keys %{$self->{_options}}) 
+      #   {
+      #   next if (generic_option($_));
+      #   $options .= $_ . '=' . $self->{_options}{$_} . '&';
+      #   }
+      # # Finally, figure out the url.
+      # $self->{_next_url} = $self->{_options}{'search_url'} .'?'. $options;
+      $self->{_next_url} = $1;
+      $state = $WEB_HITS;
+      # Stay on this line of input!
       }
-    elsif ($state eq $NEXT && m=</font>=)
+    elsif ($state eq $NEXT &&
+           s@^.*?<a href=\"(.*?)\">Group\sresults@WWWSEARCHDELETED@i)
+      {
+      print STDERR " no 'next' link\n" if 2 <= $self->{'_debug'};
+      $self->{_next_url} = undef;
+      $state = $WEB_HITS;
+      # Stay on this line of input!
+      }
+
+    if ($state eq $WEB_HITS)
+      {
+      # All the hits are on one line of input.
+      my @asHits = split /<p>/i;
+      foreach my $sHit (@asHits)
+        {
+        print STDERR "\n *   hit substring ===$sHit===" if 3 <= $self->{'_debug'};
+        if ($sHit =~ m@<b><a href=\"(.*?)\">(.*?)</a>@i)
+          {
+          my ($sURL,$sTitle) = ($1,$2);
+          if (defined($hit))
+            {
+            push(@{$self->{cache}}, $hit);
+            $self->{'_num_hits'}++;
+            } # if
+          $hits_found++;
+          $hit = new WWW::SearchResult;
+          $hit->add_url($sURL);
+          $hit->title($sTitle);
+          $hit->description($1) if ($sHit =~ m/<br>(.*?)<br>/i);
+          $hit->score($1) if ($sHit =~ m/(\d+)\%$SPACE/i);
+          $hit->change_date($1) if ($sHit =~ m/Date:\s(.*?)</i);
+          if ($sHit =~ m/Size\s(\S+?),/i)
+            {
+            my $size = $1;
+            $size =~ s/K/*1024/;
+            $size =~ s/M/*1024*1024/;
+            $hit->size(int eval $size);
+            } # if
+          } # if
+        } # foreach
+      next;
+      } # WEB_HITS
+
+    if (($state eq $NEXT || $state eq $COMP_NEXT) && m=^\s*</FONT>\s*$=i)
       {
       print STDERR " no next button\n" if 2 <= $self->{'_debug'};
       # There is no next button.
@@ -326,18 +382,22 @@ sub native_retrieve_some
       # Sometimes the </A> is on the next line.
       # Sometimes there is a /r right before the </A>
       my ($sURL,$sTitle) = ($1,$2);
-      if (defined($hit))
+      # Ignore Infoseek-internal redirects (advertisements, etc.)
+      unless ($sURL =~ m!^/redirect!i)
         {
-        push(@{$self->{cache}}, $hit);
-        }
-      $hit = new WWW::SearchResult;
-      # hits from Companies database are internal www.Infoseek.com links:
-      $sURL = 'http://www.infoseek.com'. $sURL if $sURL =~ m@^/Content@;
-      $hit->add_url($sURL);
-      $self->{'_num_hits'}++;
-      $hits_found++;
-      $hit->title($sTitle);
-      $state = $DESC;
+        # hits from Companies database are internal www.Infoseek.com links:
+        $sURL = 'http://www.infoseek.com'. $sURL if $sURL =~ m@^/Content@;
+        if (defined($hit))
+          {
+          push(@{$self->{cache}}, $hit);
+          }
+        $hit = new WWW::SearchResult;
+        $hit->add_url($sURL);
+        $self->{'_num_hits'}++;
+        $hits_found++;
+        $hit->title($sTitle);
+        $state = $DESC;
+        } # unless
       }
 
     elsif ($state eq $DESC &&
@@ -382,7 +442,7 @@ sub native_retrieve_some
       $state = $HITS;
       }
 
-    elsif ($state eq $HITS && m=Date:(&nbsp;)?\s*(\d+\s+[A-Z][a-z]+\s+\d+)=)
+    elsif ($state eq $HITS && m=Date:$SPACE(\d+\s+[A-Z][a-z]+\s+\d+)=)
       {
       print STDERR "hit change_date line\n" if 2 <= $self->{'_debug'};
       # Actual line of input is:
@@ -435,4 +495,3 @@ http://www.infoseek.com/Titles?qt=cable+tv&col=HV%2Ckt_N%2Cak_corpdir&sv=IS&lk=n
 simple Companies search:
 
 http://www.infoseek.com/Titles?qt=cable+tv&col=HV&nh=10
-
